==> material-icons-extended-1.2.1-sources.jar: androidx/compose/material/icons/sharp/Crop75.kt <==
/*
 * Copyright 2022 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.sharp

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.ImageVector

public val Icons.Sharp.Crop75: ImageVector
    get() {
        if (_crop75 != null) {
            return _crop75!!
        }
        _crop75 = materialIcon(name = "Sharp.Crop75") {
            materialPath {
                moveTo(21.0f, 7.0f)
                lineTo(3.0f, 7.0f)
                verticalLineToRelative(10.0f)
                horizontalLineToRelative(18.0f)
                lineTo(21.0f, 7.0f)
                close()
                moveTo(19.0f, 15.0f)
                lineTo(5.0f, 15.0f)
                lineTo(5.0f, 9.0f)
                horizontalLineToRelative(14.0f)
                verticalLineToRelative(6.0f)
                close()
            }
        }
        return _crop75!!
    }

private var _crop75: ImageVector? = null

==> material-icons-extended-1.3.1-sources.jar: androidx/compose/material/icons/sharp/Crop75.kt <==
/*
 * Copyright 2022 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.sharp

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.ImageVector

public val Icons.Sharp.Crop75: ImageVector
    get() {
        if (_crop75 != null) {
            return _crop75!!
        }
        _crop75 = materialIcon(name = "Sharp.Crop75") {
            materialPath {
                moveTo(21.0f, 5.0f)
                horizontalLineTo(3.0f)
                verticalLineToRelative(14.0f)
                horizontalLineToRelative(18.0f)
                verticalLineTo(5.0f)
                close()
                moveTo(19.0f, 17.0f)
                horizontalLineTo(5.0f)
                verticalLineTo(7.0f)
                horizontalLineToRelative(14.0f)
                verticalLineTo(17.0f)
                close()
            }
        }
        return _crop75!!
    }

private var _crop75: ImageVector? = null
